@@ -2,7 +2,7 @@ package RedisDB;
 
 use strict;
 use warnings;
-our $VERSION = "2.54";
+our $VERSION = "2.55";
 $VERSION = eval $VERSION;
 
 use RedisDB::Error;
@@ -1033,7 +1033,8 @@ sub _parse_cluster_nodes {
         my ( $node_id, $addr, $flags, $master_id, $ping, $pong, $state, @slots ) =
           split / /;
         my %flags = map { $_ => 1 } split /,/, $flags;
-        my ( $host, $port ) = split /:([^:]+)$/, $addr;
+        my ( $host_port ) = split /@/, $addr;
+        my ( $host, $port ) = split /:([^:]+)$/, $host_port;
         unless ($host) {
             $host = $self->{host}, $addr = "$self->{host}:$port",
         }
@@ -1768,7 +1769,7 @@ Pavel Shaydo, C<< <zwon at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2016 Pavel Shaydo.
+Copyright 2011-2019 Pavel Shaydo.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
